Installation
============

:py:mod:`py-sc-fermi` can be installed with :code:`pip`:

.. code-block:: bash 

   pip install py-sc-fermi

Alternatively, the latest development build can be found `Github`_, which can be installed by cloning the repository and installing with :code:`pip`:

.. code-block:: bash

   git clone https://github.com/bjmorgan/py-sc-fermi.git
   cd py-sc-fermi
   pip install .

.. _Github: https://github.com/bjmorgan/py-sc-fermi
